@@ -448,7 +448,7 @@ static void xlsx_raster(unsigned int *raster, int w, int h,
   for (std::vector<unsigned int>::size_type i = 0 ; i < raster_.size(); ++i) {
     raster_[i] = raster[i] ;
   }
-  gdtools::raster_to_file(raster_, w, h, width, height, (Rboolean) interpolate, os.str());
+  gdtools::raster_to_file(raster_, w, h, width*(25/6), height*(25/6), interpolate, os.str());
   fputs("<xdr:pic>", xlsx_obj->file);
     fputs("<xdr:nvPicPr>", xlsx_obj->file);
       fprintf(xlsx_obj->file,
